@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -113,7 +113,7 @@ extern "C" {
 
 # define autbegin() do {                               \
                                                        \
-  if ( AUT_DEBUG_ON ) addautdebug(__LINE__,basename(__FILE__)); } while (0)
+  if ( AUT_DEBUG_ON ) addautdebug(__LINE__,autbasename(__FILE__,NULL)); } while (0)
 
 # define autend()   do {                               \
                                                        \
@@ -268,7 +268,7 @@ extern "C" {
 |                                                       |
 \------------------------------------------------------*/
 
-  extern           void  autexit __P((int Value));
+  extern           void  autexit __P((long Value));
 
 /*------------------------------------------------------\
 |                                                       |
