@@ -43,8 +43,10 @@
 
 # include <stdio.h>
 # include <signal.h>
+# include <string.h>
 # include <stdlib.h>
 # include <unistd.h>
+# include <libgen.h>
 
 # include <mut.h>
 # include "aut.h"
