@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -221,7 +221,7 @@ autarc_list *addautgrapharc( Graph, NodeFrom, NodeTo )
   NodeFrom->ARC_FROM = addchain( NodeFrom->ARC_FROM, Arc );
   NodeTo->ARC_TO     = addchain( NodeTo->ARC_TO    , Arc );
 
-  addauth2elem( Graph->HASH_ARC, (char *)NodeFrom, (char *)NodeTo, (long)Arc );
+  addauth2elem( Graph->HASH_ARC, NodeFrom->NAME, NodeTo->NAME, (long)Arc );
 
   return( Arc );
 }
