@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -665,11 +665,13 @@ static void TestCommandViewAssoc( String )
 
   BddAssoc = BddLocalSystem->ASSOC;
 
-  if ( BddAssoc != (bddassoc *)0 )
+  while ( BddAssoc != (bddassoc *)0 )
   {
-    fprintf( stdout, "--> viewassoc\n" );
+    fprintf( stdout, "--> viewassoc %d\n", BddAssoc->IDENT );
 
     viewbddassoc( (bddsystem *)0, BddAssoc, TestViewAssoc );
+
+    BddAssoc = BddAssoc->NEXT;
   }
 }
 
