@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -72,7 +72,10 @@
   {
     "ALL",
     "VARIABLE",
-    "CONSTANT"
+    "DEFINE",
+    "ASSUME",
+    "INITIAL",
+    "RESET"
   };
 
 /*------------------------------------------------------------\
@@ -109,6 +112,10 @@ ctlfig_list *addctlfig( Name )
     Figure->HASH_DECLAR[ Type ] = createauthtable( 50 );
   }
 
+  Figure->HASH_FORM = createauthtable( 50 );
+  Figure->HASH_TYPE = createauthtable( 50 );
+  Figure->LAST_FORM = &Figure->FORM;
+
   return( Figure );
 }
 
@@ -239,51 +246,138 @@ ctldecl_list *addctldeclvar( Figure, Atom )
    ctlfig_list   *Figure;
    vexexpr       *Atom;
 {
-  ctldecl_list *Constant;
+  ctldecl_list *Variable;
   char         *Name;
 
   if ( ! IsVexNodeAtom( Atom ) ) Name = getvexarrayname( Atom );
   else                           Name = GetVexAtomValue( Atom );
 
-  Constant = searchctldeclall( Figure, Name );
+  Variable = searchctldeclall( Figure, Name );
 
-  if ( Constant != (ctldecl_list *)0 )
+  if ( Variable != (ctldecl_list *)0 )
   {
-    ctlerror( CTL_VARIABLE_EXIST_ERROR, Name, 0 );
+    ctlerror( CTL_DECLAR_EXIST_ERROR, Name, 0 );
   }
 
-  Constant = loc_addctldecl( Figure, Atom, CTL_DECLAR_VARIABLE );
+  Variable = loc_addctldecl( Figure, Atom, CTL_DECLAR_VARIABLE );
 
-  return( Constant );
+  return( Variable );
 }
 
 /*------------------------------------------------------------\
 |                                                             |
-|                     Ctl Add Declaration Constant            |
+|                     Ctl Add Declaration Define              |
 |                                                             |
 \------------------------------------------------------------*/
 
-ctldecl_list *addctldeclcst( Figure, Atom )
+ctldecl_list *addctldecldef( Figure, Atom )
 
    ctlfig_list   *Figure;
    vexexpr       *Atom;
 {
-  ctldecl_list *Constant;
+  ctldecl_list *Define;
   char         *Name;
 
   if ( ! IsVexNodeAtom( Atom ) ) Name = getvexarrayname( Atom );
   else                           Name = GetVexAtomValue( Atom );
 
-  Constant = searchctldeclall( Figure, Name );
+  Define = searchctldeclall( Figure, Name );
 
-  if ( Constant != (ctldecl_list *)0 )
+  if ( Define != (ctldecl_list *)0 )
   {
-    ctlerror( CTL_CONSTANT_EXIST_ERROR, Name, 0 );
+    ctlerror( CTL_DECLAR_EXIST_ERROR, Name, 0 );
   }
 
-  Constant = loc_addctldecl( Figure, Atom, CTL_DECLAR_CONSTANT );
+  Define = loc_addctldecl( Figure, Atom, CTL_DECLAR_DEFINE );
 
-  return( Constant );
+  return( Define );
+}
+
+/*------------------------------------------------------------\
+|                                                             |
+|                     Ctl Add Declaration Assume              |
+|                                                             |
+\------------------------------------------------------------*/
+
+ctldecl_list *addctldeclass( Figure, Atom )
+
+   ctlfig_list   *Figure;
+   vexexpr       *Atom;
+{
+  ctldecl_list *Assume;
+  char         *Name;
+
+  if ( ! IsVexNodeAtom( Atom ) ) Name = getvexarrayname( Atom );
+  else                           Name = GetVexAtomValue( Atom );
+
+  Assume = searchctldeclall( Figure, Name );
+
+  if ( Assume != (ctldecl_list *)0 )
+  {
+    ctlerror( CTL_DECLAR_EXIST_ERROR, Name, 0 );
+  }
+
+  Assume = loc_addctldecl( Figure, Atom, CTL_DECLAR_ASSUME );
+
+  return( Assume );
+}
+
+/*------------------------------------------------------------\
+|                                                             |
+|                     Ctl Add Declaration Initial             |
+|                                                             |
+\------------------------------------------------------------*/
+
+ctldecl_list *addctldeclinit( Figure, Atom )
+
+   ctlfig_list   *Figure;
+   vexexpr       *Atom;
+{
+  ctldecl_list *Initial;
+  char         *Name;
+
+  if ( ! IsVexNodeAtom( Atom ) ) Name = getvexarrayname( Atom );
+  else                           Name = GetVexAtomValue( Atom );
+
+  Initial = searchctldeclall( Figure, Name );
+
+  if ( Initial != (ctldecl_list *)0 )
+  {
+    ctlerror( CTL_DECLAR_EXIST_ERROR, Name, 0 );
+  }
+
+  Initial = loc_addctldecl( Figure, Atom, CTL_DECLAR_INITIAL );
+
+  return( Initial );
+}
+
+/*------------------------------------------------------------\
+|                                                             |
+|                     Ctl Add Declaration Reset               |
+|                                                             |
+\------------------------------------------------------------*/
+
+ctldecl_list *addctldeclreset( Figure, Atom )
+
+   ctlfig_list   *Figure;
+   vexexpr       *Atom;
+{
+  ctldecl_list *Initial;
+  char         *Name;
+
+  if ( ! IsVexNodeAtom( Atom ) ) Name = getvexarrayname( Atom );
+  else                           Name = GetVexAtomValue( Atom );
+
+  Initial = searchctldeclall( Figure, Name );
+
+  if ( Initial != (ctldecl_list *)0 )
+  {
+    ctlerror( CTL_DECLAR_EXIST_ERROR, Name, 0 );
+  }
+
+  Initial = loc_addctldecl( Figure, Atom, CTL_DECLAR_RESET );
+
+  return( Initial );
 }
 
 /*------------------------------------------------------------\
@@ -357,19 +451,16 @@ ctlform_list *addctlform( Figure, Name, Expr )
   ctlform_list *Form;
 
   Form = allocctlform();
+  Name = namealloc( Name );
 
-  Form->NAME     = namealloc( Name );;
+  Form->NAME     = Name;
   Form->VEX_EXPR = Expr;
 
-  Form->PREV     = &Figure->FORM;
-  Form->NEXT     = *(Form->PREV);
+  *Figure->LAST_FORM = Form;
+  Form->PREV         = Figure->LAST_FORM;
+  Figure->LAST_FORM  = &Form->NEXT;
 
-  if ( Form->NEXT != (ctlform_list *)0 )
-  {
-    Form->NEXT->PREV = &Form->NEXT;
-  }
-
-  *(Form->PREV) = Form;
+  addauthelem( Figure->HASH_FORM, Name, (long)Form );
 
   return( Form );
 }
@@ -397,7 +488,8 @@ ctltype_list *addctltype( Figure, Name, Index,
 
   Type = allocctltype();
 
-  Type->NAME   = namealloc( Name );;
+  Name         = namealloc( Name );
+  Type->NAME   = Name;
   Type->NEXT   = Figure->TYPE;
   Type->LEFT   = Left;
   Type->RIGHT  = Right;
@@ -408,6 +500,8 @@ ctltype_list *addctltype( Figure, Name, Index,
   Type->BASE   = Base;
   Figure->TYPE = Type;
 
+  addauthelem( Figure->HASH_TYPE, Name, (long)Type );
+
   return( Type );
 }
 
