@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -39,10 +39,10 @@ static int CtpEvalError = 0;
 
 # ifndef NO_DEBUG
 # define my_ctp_toolbug(V1,V2,V3,V4) \
-   do { fprintf( stderr, "%s.%d:", basename(__FILE__), __LINE__);\
+   do { fprintf( stderr, "%s.%d:", autbasename(__FILE__,NULL), __LINE__);\
            ctp_toolbug(V1,V2,V3,V4); } while(0)
 # define my_ctp_error(N,V) \
-   do { fprintf( stderr, "%s.%d:", basename(__FILE__), __LINE__);\
+   do { fprintf( stderr, "%s.%d:", autbasename(__FILE__,NULL), __LINE__);\
            ctp_error(N,V); } while(0)
 # else
 # define my_ctp_toolbug ctp_toolbug
