@@ -95,7 +95,9 @@
      <EnterWindow>:   CallbackEvent(  3 )\n\
      <LeaveWindow>:   CallbackEvent(  4 )\n\
      <Key>osfUp:      CallbackEvent(  5 )\n\
+     <Btn4Down>:      CallbackEvent(  5 )\n\
      <Key>osfDown:    CallbackEvent(  6 )\n\
+     <Btn5Down>:      CallbackEvent(  6 )\n\
      <Key>osfLeft:    CallbackEvent(  7 )\n\
      <Key>osfRight:   CallbackEvent(  8 )\n\
      <Key>Z:          CallbackEvent(  9 )\n\
@@ -888,7 +890,9 @@ void CallbackExpose( MyWidget, ClientData, CallData )
     DrealRefreshGraphicWindow( 0, 0, DrealGraphicDx, DrealGraphicDy );
     DrealDisplayCursor();
 
+    /* LUDO: Fed up to Click On IT ...
     DrealEnterPresentPanel();
+    */
   }
   else
   {
