@@ -325,7 +325,9 @@ void DrealLimitedLoop( MyWidget )
 
         if (WShell == DialogShell)
         {
-          XtDispatchEvent( &Event );
+          XtDispatchEventToWidget( 
+                XtWindowToWidget( AnyEvent->display, AnyEvent->window ), 
+			  &Event );
         }
         break;
 
