@@ -21,6 +21,8 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <string.h>
+#include <stdlib.h>
 #include <mut.h>
 #include <mlo.h>
 #include <mlu.h>
