@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -285,7 +285,7 @@ void vhdlsavefbarchi( pthedfbfig, synopsys )
   struct fbbus *ptfbbus   = 0;  /* current BEBUS pointer    */
   struct fbaux *ptfbaux   = 0;  /* current BEAUX pointer    */
   struct fbbux *ptfbbux   = 0;  /* current BEBUX pointer    */
-  struct biabl *ptbiabl   = 0;  /* current BIABL pointer    */
+  struct fbbiabl *ptbiabl   = 0;  /* current BIABL pointer    */
 
     /* ###------------------------------------------------------### */
     /*    Print out a concurrent assert statement for each BEMSG    */
