@@ -25,6 +25,13 @@
    Author: Frdric Ptrot
    Date  : 1/10/2000
    $Log: dpgen_Shifter.c,v $
+   Revision 1.10  2004/05/23 13:04:14  ludo
+   - Bug: Back to the previous version without bufferized command cell. Those
+   buffer cells (inv_x4 etc ..) are too big and do not fit in the first column area.
+
+   Revision 1.9  2004/03/04 14:21:56  fred
+   Adding more powerfull cells for the signals controlling the shift.
+
    Revision 1.8  2003/01/31 15:53:39  fred
    COPY_UP_SEG now copies all segments of a given name.
    This is particularly useful for CXXX layer types
@@ -108,7 +115,7 @@
 
 */
 
-static char rcsid[]="$Id: dpgen_Shifter.c,v 1.8 2003/01/31 15:53:39 fred Exp $";
+static char rcsid[]="$Id: dpgen_Shifter.c,v 1.10 2004/05/23 13:04:14 ludo Exp $";
 
 
 #include  "util_Defs.h"
