@@ -94,18 +94,18 @@ extern void genSAVE_LOFIG();
 extern void genLOINS(char *, ...);
 extern void genLOINSE(char *, ...);
 extern void genLOINSA();
-extern void genLOTRS();
-extern void genLOCON();
-extern void genLOSIGMERGE();
-extern void genFLATTEN_LOFIG();
-extern void genFLATTEN_ALL_LOINS();
-extern void genDEF_PHSC();
+extern void genLOTRS( char type, unsigned short width, unsigned short length, char *grid, char *source, char *drain );
+extern void genLOCON( char *conname, char direction, char *signame );
+extern void genLOSIGMERGE( char *sig1, char *sig2 );
+extern void genFLATTEN_LOFIG( char *insname, char concat );
+extern void genFLATTEN_ALL_LOINS( char concat, int catal );
+extern void genDEF_PHSC( char *name );
 extern void genSAVE_PHSC();
-extern void genSC_PLACE();
-extern void genSC_RIGHT();
-extern void genSC_LEFT();
-extern void genSC_TOP();
-extern void genSC_BOTTOM();
+extern void genSC_PLACE( char  *insname, int   sym, long  x, long y );
+extern void genSC_RIGHT( char  *insname, int   sym );
+extern void genSC_LEFT( char  *insname, int   sym );
+extern void genSC_TOP( char *insname, int sym );
+extern void genSC_BOTTOM( char *insname, int sym );
 extern void genSC_CHANNEL();
 extern void genSC_CON_CHANNEL();
 extern void genLOGEN(char *, int, ...);
