@@ -92,6 +92,12 @@
 
     "<Btn1Down>:      CallbackEvent(  0 )\n\
      <Btn3Down>:      CallbackEvent(  1 )\n\
+     Shift<Btn4Down>: CallbackEvent(  7 )\n\
+     Shift<Btn5Down>: CallbackEvent(  8 )\n\
+     Ctrl<Btn4Down>:  CallbackEvent(  9 )\n\
+     Ctrl<Btn5Down>:  CallbackEvent( 10 )\n\
+     <Btn4Down>:      CallbackEvent(  5 )\n\
+     <Btn5Down>:      CallbackEvent(  6 )\n\
      <Motion>:        CallbackEvent(  2 )\n\
      <EnterWindow>:   CallbackEvent(  3 )\n\
      <LeaveWindow>:   CallbackEvent(  4 )\n\
@@ -1042,7 +1048,9 @@ void CallbackExpose( MyWidget, ClientData, CallData )
     GraalRefreshGraphicWindow( 0, 0, GraalGraphicDx, GraalGraphicDy );
     GraalDisplayCursor();
 
+    /* LUDO: Fed up to Click On IT ...
     GraalEnterPresentPanel();
+    */
   }
   else
   {
