@@ -325,9 +325,11 @@ void GraalLimitedLoop( MyWidget )
       case ButtonPress   :
       case ButtonRelease :
 
-        if ( WShell == DialogShell )
+        if (WShell == DialogShell)
         {
-          XtDispatchEvent( &Event );
+          XtDispatchEventToWidget( 
+                XtWindowToWidget( AnyEvent->display, AnyEvent->window ), 
+			  &Event );
         }
 
       break;
