@@ -102,7 +102,7 @@ extern void display_error_in_abl(char* message, chain_list *abl)
 {
    if (!message || !abl) {
       fprintf(stderr,"display_error_in_abl: NULL pointer\n");
-      exit(1);
+      autexit(1);
    }
 
    fprintf(stderr,"BEH: ");
