@@ -108,15 +108,17 @@ static int loc_format_register(bereg_list* bereg)
 
    if (!bereg || !bereg->BIABL) {
       fprintf(stderr,"identify_register: NULL pointer\n");
-      exit(1);
+      autexit(1);
    }
 
+#if 0 /*to accept multiple condition block*/
    /*only one condition authorized*/
    if (bereg->BIABL->NEXT) {
       fprintf(stderr,"BEH: several conditions aren't accepted on register %s\n",
             bereg->NAME);
       return 0;            
    }
+#endif
 
    /*anyway control all condition block*/
    for (biabl=bereg->BIABL; biabl; biabl=biabl->NEXT) {
@@ -210,7 +212,7 @@ extern int format_register(befig_list* befig)
 
    if (!befig) {
       fprintf(stderr,"format_register: NULL pointer\n");
-      exit(1);
+      autexit(1);
    }
 
    BEH_ERROR=0;
