@@ -41,6 +41,14 @@
 #include "lon_signal_critical.h"
 
 
+/***************************************************************************/
+/* Global Variables                                                        */
+/***************************************************************************/
+
+static authtable *ControlLoop;
+
+
+
 
 /***************************************************************************/
 /*return the signal with the highest delay                                 */
@@ -54,7 +62,7 @@ extern losig_list* critical_output(lofig_list* lofig)
    for (losig=lofig->LOSIG; losig; losig=losig->NEXT) {
       if (!losig->NAMECHAIN) {
          fprintf(stderr,"critical_output: no losig name\n");
-         exit(1);
+         autexit(1);
       }
       signame=losig->NAMECHAIN->DATA;
       if (losig->TYPE==EXTERNAL) delay=getdelay(output_name(signame));
@@ -81,7 +89,7 @@ extern double critical_delay(lofig_list* lofig)
    
    if (!losig->NAMECHAIN) {
       fprintf(stderr,"critical_delay: no losig name\n");
-      exit(1);
+      autexit(1);
    }
    signame=losig->NAMECHAIN->DATA;
 
@@ -107,23 +115,36 @@ static ptype_list* search_long_path(losig_list* losig, int ck_include)
    ptype_list* ptype, *ret;
    double max_delay=-1, delay;
    cell_list* cell;
+   biabl_list* biabl;
 
    if (!losig) {
       fprintf(stderr,"search_long_path: NULL pointer\n");
-      exit(1);
+      autexit(1);
    }
    
    if (!losig->NAMECHAIN) {
       fprintf(stderr,"search_long_path: no losig name\n");
-      exit(1);
+      autexit(1);
    }
+
    signame=(char*) losig->NAMECHAIN->DATA;
    
+
+   /*control combinational loop, not to recurse infinitively*/
+   if ( searchauthelem( ControlLoop, (char*) losig ) )
+   {
+      fprintf(stderr,"Warning: combinational loop on signal %s\n", signame );
+      return ret;
+   }
+   
+   addauthelem( ControlLoop, (char*) losig, 1 );
+
+   
    /*search drivers*/
    ptype=getptype(losig->USER,LOFIGCHAIN);
    if (!ptype || !ptype->DATA) {
       fprintf(stderr,"search_long_path: no lofigchain found\n");
-      exit(1);
+      autexit(1);
    }
    
    for (lofigchain=(chain_list*) ptype->DATA; lofigchain; lofigchain=lofigchain->NEXT) {
@@ -131,7 +152,7 @@ static ptype_list* search_long_path(losig_list* losig, int ck_include)
       if (locon->DIRECTION==UNKNOWN) {
          fprintf(stderr,"BEH: 'linkage %s' isn't accepted\n",
          locon->NAME);
-         exit(1);
+         autexit(1);
       }
       /*only outputs*/
       if (isvss(locon->NAME) || isvdd(locon->NAME) 
@@ -154,16 +175,20 @@ static ptype_list* search_long_path(losig_list* losig, int ck_include)
    if (!cell) {
       fprintf(stderr,"library error: no cell '%s.vbe' found\n",
       loins->FIGNAME);
-      exit(1);
+      autexit(1);
    }
    befig=cell->BEFIG;
    if (befig->BEREG) {
-      ptype=getptype(befig->BEREG->BIABL->USER,ABL_STABLE);
-      if (ptype) {
-         /*do not include clock in path*/
-         if (!ck_include) return ret;
-         reg=1;
-         ck=ptype->DATA;
+      for ( biabl = cell->BEFIG->BEREG->BIABL; biabl; biabl = biabl->NEXT )
+      {
+         ptype=getptype(biabl->USER,ABL_STABLE);
+         if (ptype) {
+            /*do not include clock in path*/
+            if (!ck_include) return ret;
+            reg=1;
+            ck=ptype->DATA;
+            break;
+         }
       }
    }
    
@@ -173,7 +198,7 @@ static ptype_list* search_long_path(losig_list* losig, int ck_include)
       if (locon->DIRECTION==UNKNOWN) {
          fprintf(stderr,"BEH: 'linkage %s' in figure '%s' isn't accepted\n",
          locon->NAME,loins->FIGNAME);
-         exit(1);
+         autexit(1);
       }
       /*only inputs*/
       if (locon->DIRECTION==OUT || locon->DIRECTION==TRISTATE
@@ -183,7 +208,7 @@ static ptype_list* search_long_path(losig_list* losig, int ck_include)
       losig=locon->SIG;
       if (!losig->NAMECHAIN) {
          fprintf(stderr,"search_long_path: no name on signal\n");
-         exit(1);
+         autexit(1);
       }
       signame=(char*) losig->NAMECHAIN->DATA;
       delay=getdelay(signame);
@@ -210,11 +235,19 @@ static ptype_list* search_long_path(losig_list* losig, int ck_include)
 extern ptype_list* critical_path(lofig_list* lofig)
 {
    losig_list* losig;
+   ptype_list* ret;
    
    losig=critical_output(lofig);
    /*lofig is empty*/
    if (!losig) return NULL;
-   return (ptype_list*) reverse( (chain_list*) search_long_path(losig,1));
+   
+   ControlLoop = createauthtable( 100 );
+   
+   ret = (ptype_list*) reverse( (chain_list*) search_long_path(losig,1));
+   
+   destroyauthtable( ControlLoop );
+
+   return ret;
 }
 
 
@@ -225,11 +258,19 @@ extern ptype_list* critical_path(lofig_list* lofig)
 extern ptype_list* critical_path_without_clock(lofig_list* lofig)
 {
    losig_list* losig;
+   ptype_list* ret;
    
    losig=critical_output(lofig);
    /*lofig is empty*/
    if (!losig) return NULL;
-   return (ptype_list*) reverse( (chain_list*) search_long_path(losig,0));
+   
+   ControlLoop = createauthtable( 100 );
+   
+   ret = (ptype_list*) reverse( (chain_list*) search_long_path(losig,0));
+   
+   destroyauthtable( ControlLoop );
+
+   return ret;
 }
 
 
