@@ -25,6 +25,7 @@
 //
 // Authors-Tag 
 #include <unistd.h>
+#include <string.h>
 #include <set>
 #include <algorithm>
 #include <string>
@@ -224,14 +225,11 @@ PPlacement::Init(lofig* fig, int NbRows)
 		    it = it->NEXT)
 	    {
 		locon_list* con = (locon_list*)(it->DATA);
-		if (con->TYPE == EXTERNAL)
-		{
+		if (con->TYPE == EXTERNAL) {
 		    if ( (_prePlaceFig && _prePlaceFig->PHCON)
-                            || _placeCons || _ringPlaceCons || _iocFile)
-		    {
+                            || _placeCons || _ringPlaceCons || _iocFile) {
                         PConMap::iterator cit = pconmap.find(con->NAME);
-                        if (cit != pconmap.end())
-                        {
+                        if (cit != pconmap.end()) {
                             ++totreatinscpt;
                         }
 		    }
@@ -1533,7 +1531,8 @@ PPlacement::InitPlaceWithPrePlace()
 	  int numsubrows = CheckCreateRow(tabpreplace, yit, Width);
 	  if (numsubrows > 0)
 	  {
-	    _rows.push_back(new PRow(*this, (double)(yit * ROWHEIGHT), Width, numsubrows, orientation));
+            PRow* row = new PRow(*this, (double)(yit * ROWHEIGHT), Width, numsubrows, orientation);
+            _rows.push_back(row);
 	    _rowsYMax[(yit + 1) * ROWHEIGHT] = numrows;
 	    _rowsYMinInv[yit * ROWHEIGHT] = numrows;
 	    ++numrows;
