@@ -24,6 +24,7 @@
 // Author : Christophe Alexandre  <Christophe.Alexandre@lip6.fr>
 //
 // Authors-Tag 
+#include <string.h>
 #include "PPlacement.h"
 #include "PConstants.h"
 #include "PBBox.h"
@@ -206,5 +207,12 @@ double PRow::GetSubRowsCapa() const
 
 ostream& PRow::Print(ostream& os) const
 {
-    return os << "PRow: " << GetMinX() << ',' << GetMinY() << " : " << GetMaxX() << ',' << GetMaxY();
+    string orientation;
+    if (_orientation) {
+        orientation = "ON";
+    } else {
+        orientation = "OFF";
+    }
+    return os << "PRow: " << GetMinX() << ',' << GetMinY() <<
+        " : " << GetMaxX() << ',' << GetMaxY() << "," << orientation;
 }
