@@ -49,7 +49,7 @@ long          *typ   ;			/* child struct. or data type	*/
 char         **str   ;			/* recognized strings		*/
   {
 
-  int            i;
+  long           i;
 
   struct paseq  *paseq_pnt;
   struct pagrp  *pagrp_pnt;
@@ -62,7 +62,7 @@ char         **str   ;			/* recognized strings		*/
 
   char         **string_pnt;
   char          *character_pnt;
-  int           *integer_pnt;
+  long          *integer_pnt;
 
 	/* ###------------------------------------------------------### */
 	/*    initialization						*/
@@ -350,7 +350,7 @@ char         **str   ;			/* recognized strings		*/
 
     case integer_DFN :
 
-      integer_pnt = (int *) curpnt.data;
+      integer_pnt = (long *) curpnt.data;
 
       typ [integer_DFN]     = IMMEDIATE_DFN | d_DFN | integer_DFN;
       pnt [integer_DFN].imd = *integer_pnt;
@@ -390,7 +390,7 @@ char         **str   ;			/* recognized strings		*/
           break;
 
         case u_DFN :
-          printf ("%u\n", (unsigned int) pnt[i].imd);
+          printf ("%lu\n", (unsigned long) pnt[i].imd);
           break;
 
         case c_DFN :
@@ -398,7 +398,7 @@ char         **str   ;			/* recognized strings		*/
           break;
 
         case d_DFN :
-          printf ("%d\n", (int) pnt[i].imd);
+          printf ("%ld\n", (long) pnt[i].imd);
           break;
 
         case l_DFN :
@@ -406,7 +406,7 @@ char         **str   ;			/* recognized strings		*/
           break;
 
         case x_DFN :
-          printf ("0x%x\n", (unsigned int) pnt[i].imd);
+          printf ("0x%lx\n", (unsigned long) pnt[i].imd);
           break;
         }
       }
@@ -439,17 +439,17 @@ char         **str   ;			/* recognized strings		*/
 /* called func.	: none							*/
 /* ###--------------------------------------------------------------### */
 
-static int splitline (words, line)
+static long splitline (words, line)
 
 char **words;
 char  *line ;
   {
 
   char *heap   = *words;
-  int   new    =  1;
-  int   wrdcnt =  0;
-  int   i      =  0;
-  int   j      =  0;
+  long   new    =  1;
+  long   wrdcnt =  0;
+  long   i      =  0;
+  long   j      =  0;
 
 	/* ###------------------------------------------------------### */
 	/*    copy the line read from input into the words until a	*/
@@ -490,12 +490,12 @@ char  *line ;
 static void push (stk, stkpnt, data, type)
 
 struct stack *stk;
-int          *stkpnt;
+long          *stkpnt;
 void         *data;
 short         type;
 
   {
-  int stkidx = *stkpnt;
+  long stkidx = *stkpnt;
 
   if (stkidx == STKSIZ_DFN)
     pat_message (2, "pat_debug", NULL, 0);
@@ -522,11 +522,11 @@ short         type;
 
 static void pop (stkpnt, count)
 
-int          *stkpnt;
-int           count;
+long          *stkpnt;
+long           count;
 
   {
-  int stkidx = *stkpnt;
+  long stkidx = *stkpnt;
 
   if (stkidx <= count)
     stkidx = 0;
@@ -546,7 +546,7 @@ int           count;
 static struct chain *go_forward (pnt, count)
 
 struct chain *pnt;
-int           count;
+long           count;
 
   {
   while ((count > 0) && (pnt != NULL) && (pnt->NEXT != NULL))
@@ -565,17 +565,17 @@ int           count;
 /* called func.	: none							*/
 /* ###--------------------------------------------------------------### */
 
-static int translate (words, wrdcnt, strgs, nmbrs, flags, indxs)
+static long translate (words, wrdcnt, strgs, nmbrs, flags, indxs)
 
 char **words ;				/* list of words		*/
-int    wrdcnt;				/* number of words		*/
+long    wrdcnt;				/* number of words		*/
 char **strgs ;				/* list of recognized strings	*/
-int   *nmbrs ;				/* words translated to numbers	*/
+long   *nmbrs ;				/* words translated to numbers	*/
 char  *flags ;				/* set if word is a number	*/
-int   *indxs ;				/* words' index in strgs table	*/
+long   *indxs ;				/* words' index in strgs table	*/
 
   {
-  int i , j;
+  long i , j;
 
 	/* ###------------------------------------------------------### */
 	/*    initialize flags and indxs				*/
@@ -611,10 +611,10 @@ int   *indxs ;				/* words' index in strgs table	*/
 
 static void get_size (siz)
 
-unsigned int siz [];
+unsigned long siz [];
 
   {
-  int i;
+  long i;
  
   for (i=0 ; i<MAXCMD_DFN ; i++)
     siz [i] = 0;
@@ -650,7 +650,7 @@ static void disp_immd (str, pnt , type)
 
 char        **str;
 union value pnt  ;
-int         type ;
+long         type ;
 
   {
   printf ("   %-15s: ", str [type]);
@@ -669,7 +669,7 @@ int         type ;
     case short_DFN     :
     case integer_DFN   :
     case long_DFN      :
-      printf ("0x%x\n", (unsigned int) pnt.imd);
+      printf ("0x%lx\n", (unsigned long) pnt.imd);
       break;
 
     default :
@@ -697,24 +697,24 @@ char *type;				/* structure's type		*/
   char          buffer [128];		/* buffer to split the cmd line	*/
 
   char         *words  [ 10];		/* number of words on a line	*/
-  int           nmbrs  [ 10];		/* words translated into number	*/
+  long          nmbrs  [ 10];		/* words translated into number	*/
   char          flags  [ 10];		/* set if words is a number	*/
-  int           indxs  [ 10];		/* index of words		*/
+  long          indxs  [ 10];		/* index of words		*/
 
   struct stack  jtab   [ 10];		/* list of memorized addresses	*/
-  int           idx;
-  int           readflg = 0;
-  unsigned int  size;
+  long          idx;
+  long          readflg = 0;
+  unsigned long size;
   char         *pntr   = NULL;
   long          pshtype;
-  int           wrdcnt = 1;
+  long          wrdcnt = 1;
 
   struct stack  stk [STKSIZ_DFN];
-  int           stkpnt = -1;
+  long          stkpnt = -1;
 
   union value   pnt [MAXCMD_DFN];
   long          typ [MAXCMD_DFN];
-  unsigned int  siz [MAXCMD_DFN];
+  unsigned long  siz [MAXCMD_DFN];
 
   static char  *str [] = {
                           "_back"    , "_exit"    , "_jump"    , "_save"    ,
@@ -961,7 +961,7 @@ char *type;				/* structure's type		*/
             {
             size = siz [(typ [idx] & TYPE_DFN)];
             pntr = (void *)
-                   (((unsigned int) pnt [idx].dat) + (size * nmbrs [1]));
+                   (((unsigned long) pnt [idx].dat) + (size * nmbrs [1]));
             push (stk, &stkpnt, pntr, pshtype);
             readflg = 1;
             }
@@ -978,7 +978,7 @@ char *type;				/* structure's type		*/
             {
             size = sizeof (void *);
             pntr = * (void **)
-                     (((unsigned int) pnt [idx].dat) + (size * nmbrs [1]));
+                     (((unsigned long) pnt [idx].dat) + (size * nmbrs [1]));
             push (stk, &stkpnt, pntr, pshtype);
             readflg = 1;
             }
