@@ -94,7 +94,7 @@
 |                                                       |
 \------------------------------------------------------*/
 
-        scpcol_list   *HEAD_SCPCOL;
+extern scpcol_list   *HEAD_SCPCOL;
 
 /*------------------------------------------------------\
 |                                                       |
