@@ -432,10 +432,11 @@ static void VasyVerilogTreatAsg( RtlFigure, RtlAsg )
              ( RtlType == RTL_BIVEX_FALLING_EDGE ) )
         {
           VexCond  = RtlBiVex->VEX_COND;
+
           SensName = GetVexAtomValue( VexCond );
 
-          if ( RtlType == RTL_BIVEX_FALLING_EDGE ) SensType = VASY_VERILOG_SENS_POSEDGE;
-          else                                     SensType = VASY_VERILOG_SENS_NEGEDGE;
+          if ( RtlType == RTL_BIVEX_FALLING_EDGE ) SensType = VASY_VERILOG_SENS_NEGEDGE;
+          else                                     SensType = VASY_VERILOG_SENS_POSEDGE;
 
           SensList = addptype( SensList, SensType, SensName );
         }
@@ -577,7 +578,8 @@ static void VasyDriveVerilogPort( RtlFigure )
         RtlDeclar != (rtldecl_list *)NULL;
         RtlDeclar = RtlDeclar->NEXT )
   {
-     if ( ! IsVasyRtlDeclType( RtlDeclar, VASY_RTL_DECL_COMBINATORIAL ) )
+	  if ( IsVasyRtlDeclType( RtlDeclar, VASY_RTL_DECL_REGISTER )
+	    || IsVasyRtlDeclType( RtlDeclar, VASY_RTL_DECL_TRISTATE ) )
      {
        VexPort  = RtlDeclar->VEX_ATOM;
        PortName = GetVexAtomValue( VexPort );
