@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -443,6 +443,7 @@
 # define SetVexAtomValue( N, A )  ( (N)->VALUE = (void *)(A) )
 
 # define GetVexOperand( C )       ( (vexexpr *)(C)->DATA     )
+# define GetVexOperandL( C )      ( (C)->DATA                )
 # define SetVexOperand( C, O )    ( (C)->DATA = (void *)(O)  )
 
 /*------------------------------------------------------\
