@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -184,7 +184,7 @@ int getvexintnumbit( Size )
   if ( Size <  0 ) return( 0 );
   if ( Size == 0 ) return( 1 );
 
-  Mask = 1L << 31;
+  Mask = 1U << 31;
 
   for ( NumberBit = 32; NumberBit > 0; NumberBit-- )
   {
