@@ -79,7 +79,7 @@
 |                                                             |
 \------------------------------------------------------------*/
 
-  static char *XfsmPanelButtonDisable = "xxxx";
+  char *XfsmPanelButtonDisable = "xxxx";
 
 /*------------------------------------------------------------\
 |                                                             |
