@@ -77,7 +77,7 @@
 |                                                             |
 \------------------------------------------------------------*/
 
-  static char *XpatPanelButtonDisable = "xxxx";
+  char *XpatPanelButtonDisable = "xxxx";
 
 /*------------------------------------------------------------\
 |                                                             |
