@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU General Public |
@@ -750,7 +750,7 @@ static void XschDrawTransistor( X1r, Y1r, X2r, Y2r, Ycr, Obj )
              XschDrawGC,
              x1, y0 - cs, x1, y2 + cs );
 
-  if ( ( Obj->ARG1 ) == 0 )
+  if ( ( Obj->ARG1 ) == 1 ) /* This is TRANSN */
   {
      /* Output line : centered vertically */
      XDrawLine( XschGraphicDisplay, XschGraphicPixmap, XschDrawGC,
