@@ -44,6 +44,8 @@
 \------------------------------------------------------------*/
 
 # include <stdio.h>
+# include <stdlib.h>
+# include <string.h>
 # include "mut.h"
 # include "aut.h"
 # include "XSB.h"
