@@ -76,7 +76,7 @@
 |                                                             |
 \------------------------------------------------------------*/
 
-  static char *XvpnPanelButtonDisable = "xxxx";
+  char *XvpnPanelButtonDisable = "xxxx";
 
 /*------------------------------------------------------------\
 |                                                             |
